==> deepin-qt5integration-debug-5.6.26-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-qt5integration/qt5integration-5.6.26/platformthemeplugin/qdeepin_autogen/EWIEGA46WW/qrc_deepin-theme-plugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.13
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/deepin-qt5integration/src/qt5integration-5.6.26/platformthemeplugin/qtquickcontrols2.conf
  0x0,0x0,0x0,0x1a,
  0x5b,
  0x43,0x6f,0x6e,0x74,0x72,0x6f,0x6c,0x73,0x5d,0xa,0x53,0x74,0x79,0x6c,0x65,0x3d,
  0x43,0x68,0x61,0x6d,0x65,0x6c,0x65,0x6f,0x6e,
  
};

static const unsigned char qt_resource_name[] = {
  // qtquickcontrols2.conf
  0x0,0x15,
  0x8,0x1e,0x16,0x66,
  0x0,0x71,
  0x0,0x74,0x0,0x71,0x0,0x75,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,0x6c,0x0,0x73,0x0,0x32,0x0,0x2e,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x66,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x8e,0x89,0x20,0x34,0x88,
  // :/qtquickcontrols2.conf
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x8e,0x89,0x20,0x34,0x88,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_deepin_theme_plugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_deepin_theme_plugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_deepin_theme_plugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_deepin_theme_plugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_deepin_theme_plugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_deepin_theme_plugin)(); }
   } dummy;
}

==> deepin-qt5integration-debug-5.6.26-2-x86_64.pkg.tar.zst: usr/src/debug/deepin-qt5integration/qt5integration-5.6.26/platformthemeplugin/qdeepin_autogen/EWIEGA46WW/qrc_deepin-theme-plugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.13
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/deepin-qt5integration/src/qt5integration-5.6.26/platformthemeplugin/qtquickcontrols2.conf
  0x0,0x0,0x0,0x1a,
  0x5b,
  0x43,0x6f,0x6e,0x74,0x72,0x6f,0x6c,0x73,0x5d,0xa,0x53,0x74,0x79,0x6c,0x65,0x3d,
  0x43,0x68,0x61,0x6d,0x65,0x6c,0x65,0x6f,0x6e,
  
};

static const unsigned char qt_resource_name[] = {
  // qtquickcontrols2.conf
  0x0,0x15,
  0x8,0x1e,0x16,0x66,
  0x0,0x71,
  0x0,0x74,0x0,0x71,0x0,0x75,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,0x6c,0x0,0x73,0x0,0x32,0x0,0x2e,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x66,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x8f,0xf,0x2f,0xe0,0x78,
  // :/qtquickcontrols2.conf
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x8f,0xf,0x2f,0xe0,0x78,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_deepin_theme_plugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_deepin_theme_plugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_deepin_theme_plugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_deepin_theme_plugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_deepin_theme_plugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_deepin_theme_plugin)(); }
   } dummy;
}
